@@ -611,6 +611,6 @@ class PlainTextHelper
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/EmailBundle/Helper/PlainTextHelper.php", "/var/www/html/mauticGIT-Test/app/bundles/EmailBundle/Helper/PlainTextHelper.php");
+        return new Source("", "@bundles/EmailBundle/Helper/PlainTextHelper.php", "/var/www/html/production-demo/app/bundles/EmailBundle/Helper/PlainTextHelper.php");
     }
 }
