@@ -241,6 +241,6 @@ class __TwigTemplate_684c8f2695f6800aba8699717bdf9435 extends Template
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@themes/oxygen/html/email.html.twig", "/var/www/html/mauticGIT-Test/themes/oxygen/html/email.html.twig");
+        return new Source("", "@themes/oxygen/html/email.html.twig", "/var/www/html/production-demo/themes/oxygen/html/email.html.twig");
     }
 }
