@@ -685,6 +685,6 @@ class TriggerController extends FormController
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/PointBundle/Controller/TriggerController.php", "/var/www/html/mauticGIT-Test/app/bundles/PointBundle/Controller/TriggerController.php");
+        return new Source("", "@bundles/PointBundle/Controller/TriggerController.php", "/var/www/html/production-demo/app/bundles/PointBundle/Controller/TriggerController.php");
     }
 }
