@@ -211,6 +211,6 @@ class __TwigTemplate_e52e63e1c6a90f3d52017633ce710d1a extends Template
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@MauticCampaign/Event/_generic.html.twig", "/var/www/html/mauticGIT-Test/app/bundles/CampaignBundle/Resources/views/Event/_generic.html.twig");
+        return new Source("", "@MauticCampaign/Event/_generic.html.twig", "/var/www/html/production-demo/app/bundles/CampaignBundle/Resources/views/Event/_generic.html.twig");
     }
 }
