@@ -757,6 +757,6 @@ class CommonController extends AbstractController implements MauticController
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/CoreBundle/Controller/CommonController.php", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Controller/CommonController.php");
+        return new Source("", "@bundles/CoreBundle/Controller/CommonController.php", "/var/www/html/production-demo/app/bundles/CoreBundle/Controller/CommonController.php");
     }
 }
