@@ -330,6 +330,6 @@ class __TwigTemplate_421583ce9c4f4b2e1bf3bc8c44de945a extends Template
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@MauticCore/Helper/tabs.html.twig", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Resources/views/Helper/tabs.html.twig");
+        return new Source("", "@MauticCore/Helper/tabs.html.twig", "/var/www/html/production-demo/app/bundles/CoreBundle/Resources/views/Helper/tabs.html.twig");
     }
 }
