@@ -509,6 +509,6 @@ class PublicController extends CommonFormController
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/FormBundle/Controller/PublicController.php", "/var/www/html/mauticGIT-Test/app/bundles/FormBundle/Controller/PublicController.php");
+        return new Source("", "@bundles/FormBundle/Controller/PublicController.php", "/var/www/html/production-demo/app/bundles/FormBundle/Controller/PublicController.php");
     }
 }
