@@ -1382,6 +1382,6 @@ class Email extends FormEntity implements VariantEntityInterface, TranslationEnt
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/EmailBundle/Entity/Email.php", "/var/www/html/mauticGIT-Test/app/bundles/EmailBundle/Entity/Email.php");
+        return new Source("", "@bundles/EmailBundle/Entity/Email.php", "/var/www/html/production-demo/app/bundles/EmailBundle/Entity/Email.php");
     }
 }
