@@ -146,6 +146,6 @@ class __TwigTemplate_0c03cbbf8bacebcc2ea709ea6894c6ca extends Template
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/PageBundle/Assets/builder/pick-a-color.css", "/var/www/html/mauticGIT-Test/app/bundles/PageBundle/Assets/builder/pick-a-color.css");
+        return new Source("", "@bundles/PageBundle/Assets/builder/pick-a-color.css", "/var/www/html/production-demo/app/bundles/PageBundle/Assets/builder/pick-a-color.css");
     }
 }
