@@ -562,6 +562,6 @@ class InstallService
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/InstallBundle/Install/InstallService.php", "/var/www/html/mauticGIT-Test/app/bundles/InstallBundle/Install/InstallService.php");
+        return new Source("", "@bundles/InstallBundle/Install/InstallService.php", "/var/www/html/production-demo/app/bundles/InstallBundle/Install/InstallService.php");
     }
 }
