@@ -391,6 +391,6 @@ return [
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/EmailBundle/Config/config.php", "/var/www/html/mauticGIT-Test/app/bundles/EmailBundle/Config/config.php");
+        return new Source("", "@bundles/EmailBundle/Config/config.php", "/var/www/html/production-demo/app/bundles/EmailBundle/Config/config.php");
     }
 }
