@@ -2248,6 +2248,6 @@ class MailHelper
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/EmailBundle/Helper/MailHelper.php", "/var/www/html/mauticGIT-Test/app/bundles/EmailBundle/Helper/MailHelper.php");
+        return new Source("", "@bundles/EmailBundle/Helper/MailHelper.php", "/var/www/html/production-demo/app/bundles/EmailBundle/Helper/MailHelper.php");
     }
 }
