@@ -850,6 +850,6 @@ class __TwigTemplate_44a5149b5349165066267914cfa9f0b5 extends Template
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/CoreBundle/Assets/css/libraries/font-awesome/less/icons.less", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Assets/css/libraries/font-awesome/less/icons.less");
+        return new Source("", "@bundles/CoreBundle/Assets/css/libraries/font-awesome/less/icons.less", "/var/www/html/production-demo/app/bundles/CoreBundle/Assets/css/libraries/font-awesome/less/icons.less");
     }
 }
